@@ -1,7 +1,7 @@
 pub mod events;
 pub mod key;
 
-use self::key::Key;
+use crate::inputs::key::Key;
 
 pub enum InputEvent {
     Input(Key),
